@@ -1,10 +1,7 @@
 #' List cached files
 #'
 #' @export
-#' @param cache_path path to cached files
-#' @references \url{https://upwell.pfeg.noaa.gov/erddap/index.html}
-#' @author Scott Chamberlain <myrmecocystus@@gmail.com>
-#' @seealso \code{\link{cache_delete}}, \code{\link{cache_details}}
+#' @family cache
 #' @examples \dontrun{
 #' # list files in cache
 #' (x <- cache_list())
@@ -18,9 +15,9 @@
 #' # cache_delete(x$nc[1])
 #' # cache_delete(x$nc[2:3])
 #' }
-cache_list <- function(cache_path = "~/.rerddap") {
-  nc_files <- list.files(cache_path, pattern = ".nc")
-  csv_files <- list.files(cache_path, pattern = ".csv")
+cache_list <- function() {
+  nc_files <- list.files(rrcache$cache_path_get(), pattern = ".nc")
+  csv_files <- list.files(rrcache$cache_path_get(), pattern = ".csv")
   structure(list(nc = nc_files, csv = csv_files), class = "rerddap_cache")
 }
 
