@@ -3,7 +3,8 @@
 #' @export
 #' @param udunits character; A UDUNITS character string
 #' \url{http://www.unidata.ucar.edu/software/udunits/}
-#' @param ucum character; A UCUM character string \url{http://unitsofmeasure.org/ucum.html}
+#' @param ucum character; A UCUM character string
+#' \url{http://unitsofmeasure.org/ucum.html}
 #' @param url Base URL of the ERDDAP server
 #' @param ... Curl args passed on to \code{\link[httr]{GET}}
 #' @examples  \dontrun{
@@ -11,7 +12,9 @@
 #' convert_units(ucum = "Cel.m-1")
 #' }
 
-convert_units <- function(udunits = NULL, ucum = NULL, url="http://coastwatch.pfeg.noaa.gov", ...){
+convert_units <- function(udunits = NULL, ucum = NULL,
+                          url="http://coastwatch.pfeg.noaa.gov", ...) {
+
   check1notboth(udunits, ucum)
   args <- rc(list(UDUNITS = udunits, UCUM = ucum))
   res <- GET(paste0(pu(url), '/erddap/convert/units.txt'), query = args, ...)
